@@ -2,14 +2,10 @@ package Alien::FFI;
 
 use strict;
 use warnings;
-use Config;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build and make available libffi
-our $VERSION = '0.24_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
-
-
+our $VERSION = '0.01'; # VERSION
 
 
 1;
@@ -26,20 +22,17 @@ Alien::FFI - Build and make available libffi
 
 =head1 VERSION
 
-version 0.24_01
+version 0.01
 
 =head1 SYNOPSIS
 
-In your Build.PL:
+In your C<Build.PL>:
 
- use Module::Build;
  use Alien::FFI;
- my $builder = Module::Build->new(
+ use Module::Build;
+ 
+ my $build = Module::Build->new(
    ...
-   configure_requires => {
-     'Alien::FFI' => '0',
-     ...
-   },
    extra_compiler_flags => Alien::FFI->cflags,
    extra_linker_flags   => Alien::FFI->libs,
    ...
@@ -47,50 +40,24 @@ In your Build.PL:
  
  $build->create_build_script;
 
-In your Makefile.PL:
+In your L<FFI::Raw> script:
 
- use ExtUtils::MakeMaker;
- use Config;
  use Alien::FFI;
+ use FFI::Raw;
  
- WriteMakefile(
-   ...
-   CONFIGURE_REQUIRES => {
-     'Alien::FFI' => '0',
-   },
-   CCFLAGS => Alien::FFI->cflags . " $Config{ccflags}",
-   LIBS    => [ Alien::FFI->libs ],
-   ...
- );
+ my($dll) = Alien::FFI->dynamic_libs;
+ FFI::Raw->new($dll, '...', ...);
 
 =head1 DESCRIPTION
 
 This distribution installs libffi so that it can be used by other Perl distributions.  If already
 installed for your operating system, and it can be found, this distribution will use the libffi
 that comes with your operating system, otherwise it will download it from the Internet, build and
-install it for you.
-
-=head1 SEE ALSO
-
-=over 4
-
-=item L<FFI::Platypus>
-
-Write Perl bindings to non-Perl libraries without C or XS
-
-=item L<FFI::CheckLib>
-
-Check that a library is available for FFI
-
-=back
+install it fro you.
 
 =head1 AUTHOR
 
-Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Petr Pisar (ppisar)
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
